$TITLE Summary of simulation reports. Standard CGE modeling system, Version 1.00
$ontext
Version 1.00 Release date: May 02, 2001
Last update:
$offtext

PARAMETERS
*This group of parameters are used for various price-index calculations.
 pdwt(C)  weight of commodity c in PD index
 pwewt(C) weight of commodity c in pwe index
 pwmwt(C) weight of commodity c in pwm index
 pwwt(*)  weight of aggregate exports-imports in pw (tradables) index

*These two parameters are used in the computation of EVTAB

 IC(H,SIM)        indirect compensation fn by hhd h and simulation sim
*IC measure the income needed at base prices to generate same welfare
*as under prices and income under sim

 EV(H,SIM)        equivalent variation by hhd h and simulation sim
*EV measures the income change that, at base prices, would be
*equivalent to the change simulated for sim.

$ontext
Source for IC and EV formulas (here adapted to fit demand system
with home and market consumption):
Blonigen, Bruce A., Joseph E. Flynn, and Kenneth A. Reinert
(1997) Sector-Focused General Equilibrium Modeling, pp. 189-230
in eds. Joseph F. Francois and Kenneth A. Reinert, Applied Methods
for Trade Policy Analysis. Cambridge, MA: Cambridge University Press
The formulas are on pp. 224-225.
$offtext
 ;

 pdwt(C)  = PDD0(C)*QD0(C)/SUM(CP, PDD0(CP)*QD0(CP));
 pwewt(C) = pwe0(C)*QE0(C)/SUM(CP, pwe0(CP)*QE0(CP));
 pwmwt(C) = pwm0(C)*QM0(C)/SUM(CP, pwm0(CP)*QM0(CP));
 pwwt('EXP')
  = SUM(CP, pwe0(CP)*QE0(CP))
    / (SUM(CP, pwe0(CP)*QE0(CP)) + SUM(CP, pwm0(CP)*QM0(CP)) );
 pwwt('IMP')
  = SUM(CP, pwm0(CP)*QM0(CP))
    / (SUM(CP, pwe0(CP)*QE0(CP)) + SUM(CP, pwm0(CP)*QM0(CP)) );

 IC(H,SIMCUR)
  = (
     ( EHX(H,SIMCUR)
     - SUM(C, PQX(C,SIMCUR)*gammam(C,H))
     - SUM((A,C), PXACX(A,C,SIMCUR)*gammah(A,C,H)) )
      /
     ( PROD(C, PQX(C,SIMCUR)**betam(C,H))
                        *PROD((A,C), PXACX(A,C,SIMCUR)**betah(A,C,H)) )
      )
   *( PROD(C, PQ0(C)**betam(C,H))
                        *PROD((A,C), PXAC0(A,C)**betah(A,C,H)) )
     + SUM(C, PQ0(C)*gammam(C,H)) + SUM((A,C), PXAC0(A,C)*gammah(A,C,H));

 EV(H,SIMCUR) = IC(H,SIMCUR) - EH0(H);


DISPLAY
 pdwt, pwewt, pwmwt, pwwt
 IC, EV;


SET
 SIND Macro summary indicators
 /
*Real quantities, exchange rates and price indices
 QABSTOT real absorption (LCU at base prices)
 QHTOT   real household consumption (LCU at base prices)
 QINVTOT real investment (LCU at base prices)
 QGTOT   real government consumption (LCU at base prices)
 QETOT   total real exports (LCU at base prices)
 QMTOT   total real imports (LCU at base prices)
 REXR    PPP real exchange rate (LCUs per FCU)
 NEXR    nominal exchange rate (LCUs per FCU)
 PWEIND  exports price index (FCU -- 100 for base)
 PWMIND  imports price index (FCU -- 100 for base)
 PWIND   world (tradables) price index (FCU -- 100 for base)
 PDIND   domestic (non-tradables) price index (100 for base)
 CPI     consumer price index (100 for base)
 TOFT    terms of trade (ratio pwe index & pwm index) (100 for base)

*Nominal GDP shares
 INVGDP     investment (% of nominal GDP)
 PRVSAVGDP  private (household + enterprise) savings (% of nominal GDP)
 FORSAVGDP  foreign savings (% of nominal GDP)
 TRDDEFGDP  trade deficit (% of nominal GDP)
 GOVSAVGDP  government savings (% of nominal GDP)
 IMPTAXGDP  tariff revenue (% of nominal GDP)
 DIRTAXGDP  direct tax revenue (% of nominal GDP)
 /

SINDDEV(SIND) summary indicators showing deviation from BASE
 /
 INVGDP     investment (% of nominal GDP)
 PRVSAVGDP  private (household + enterprise) savings (% of nominal GDP)
 FORSAVGDP  foreign savings (% of nominal GDP)
 TRDDEFGDP  trade deficit  (% of nominal GDP)
 GOVSAVGDP  government savings (% of nominal GDP)
 IMPTAXGDP  import tax revenue (% of nominal GDP)
 DIRTAXGDP  direct tax revenue (% of nominal GDP)
 /

 SIMNB(SIM) non-base simulations

 SINDP(SIND)  summary indicators showing percent change
 ;

SIMNB(SIM)    = YES;
SIMNB('BASE') = NO;
SINDP(SIND)$(NOT SINDDEV(SIND)) = YES;

DISPLAY SIMNB, SINDP;

PARAMETER
 MACROTAB(SIND,SIM) Macro table
 QHTAB(AC,SIM)      Disaggregated real household consumption
 EVTAB(AC,SIM)      Disaggregated EV
 YFTAB(AC,SIM)      Disaggregated factor income distribution
 QATAB(AC,SIM)      Disaggregated activity production levels
 PATAB(AC,SIM)      Disaggregated activity prices
 ;

*MACROTAB=====================================

MACROTAB('QINVTOT',SIMCUR) = SUM(C, PQ0(C)*QINVX(C,SIMCUR));
MACROTAB('QGTOT',SIMCUR)   = SUM(C, PQ0(C)*QGX(C,SIMCUR));
MACROTAB('QHTOT',SIMCUR)   = SUM((C,H), PQ0(C)*QHX(C,H,SIMCUR));
MACROTAB('QABSTOT',SIMCUR)
  = MACROTAB('QINVTOT',SIMCUR) + MACROTAB('QGTOT',SIMCUR)
  + MACROTAB('QHTOT',SIMCUR);

MACROTAB('QETOT',SIMCUR)  = SUM(C, PE0(C)*QEX(C,SIMCUR));
MACROTAB('QMTOT',SIMCUR)  = SUM(C, PM0(C)*QMX(C,SIMCUR));

MACROTAB('CPI',SIMCUR)    = 100*cpix(SIMCUR)/cpix('BASE');
MACROTAB('NEXR',SIMCUR)   = 100*EXRX(SIMCUR);
MACROTAB('PDIND',SIMCUR)  = 100*SUM(C, pdwt(C)*PDDX(C,SIMCUR));

MACROTAB('PWEIND',SIMCUR)
  = 100*SUM(C, pwex(C,SIMCUR)*pwewt(C))
    /SUM(C, pwex(C,'BASE')*pwewt(C));
MACROTAB('PWMIND',SIMCUR)
  = 100*SUM(C, pwmx(C,SIMCUR)*pwmwt(C))
    /SUM(C, pwmx(C,'BASE')*pwmwt(C));;

MACROTAB('TOFT',SIMCUR)
  = 100*MACROTAB('PWEIND',SIMCUR)/MACROTAB('PWMIND',SIMCUR);

MACROTAB('PWIND',SIMCUR)
  =  pwwt('EXP')*MACROTAB('PWEIND',SIMCUR)
  +  pwwt('IMP')*MACROTAB('PWMIND',SIMCUR);


MACROTAB('REXR',SIM)$SIMCUR(SIM)
 = MACROTAB('NEXR',SIM)*MACROTAB('PWIND',SIM)/MACROTAB('PDIND',SIM)
* /(MACROTAB('NEXR','BASE')*MACROTAB('PWIND','BASE')
*                                        /MACROTAB('PDIND','BASE'))
  ;

 MACROTAB('INVGDP',SIMCUR)
  = 100*SUM(C, PQX(C,SIMCUR)*QINVX(C,SIMCUR))
    /GDPTAB1('NOMINAL','GDPMP',SIMCUR);

 MACROTAB('PRVSAVGDP',SIMCUR)
  = 100*SUM(INSDNG, SAMBUD('INSDNG',INSDNG,'SPND','S-I',SIMCUR))
    /GDPTAB1('NOMINAL','GDPMP',SIMCUR);

 MACROTAB('FORSAVGDP',SIMCUR)
   = 100*EXRX(SIMCUR)*FSAVX(SIMCUR)
     /GDPTAB1('NOMINAL','GDPMP',SIMCUR);

 MACROTAB('TRDDEFGDP',SIMCUR)
   = 100*(SUM(C, PMX(C,SIMCUR)*QMX(C,SIMCUR))
     - SUM(C, PEX(C,SIMCUR)*QEX(C,SIMCUR)))
     /GDPTAB1('NOMINAL','GDPMP',SIMCUR);

 MACROTAB('GOVSAVGDP',SIMCUR)
   = 100*SAMBUD('GOV','DUM','SPND','S-I',SIMCUR)
     /GDPTAB1('NOMINAL','GDPMP',SIMCUR);

 MACROTAB('IMPTAXGDP',SIMCUR)
   = 100*SAMBUD('GOV','DUM','INC','IMPTAX',SIMCUR)
     /GDPTAB1('NOMINAL','GDPMP',SIMCUR);

 MACROTAB('DIRTAXGDP',SIMCUR)
   = 100*(SAMBUD('GOV','DUM','INC','INSTAX',SIMCUR)
     + SAMBUD('GOV','DUM','INC','FACTAX',SIMCUR))
     /GDPTAB1('NOMINAL','GDPMP',SIMCUR);


*TABLES OTHER THAN MACROTAB===============================

 QHTAB(H,SIMCUR)       = SUM(C, PQ0(C)*QHX(C,H,SIMCUR));
 QHTAB('TOTAL',SIMCUR) = SUM((C,H), PQ0(C)*QHX(C,H,SIMCUR));

 EVTAB(H,'BASE') = EH0(H);
 EVTAB(H,SIMNB)  = 100*EV(H,SIMNB)/EH0(H);

 YFTAB(F,SIMCUR)
   = 100*SAMBUD('FAC',F,'INC','TOTAL',SIMCUR)
     /SUM(FP, SAMBUD('FAC',FP,'INC','TOTAL',SIMCUR));
 YFTAB('TOTAL',SIMCUR) = SUM(F, YFTAB(F,SIMCUR));

 QATAB(A,SIMCUR)       = PA0(A)*QAX(A,SIMCUR);
 QATAB('TOTAL',SIMCUR) = SUM(A, PA0(A)*QAX(A,SIMCUR));

 PATAB(A,SIMCUR)       = 100*PAX(A,SIMCUR);

*==============================================
*Computing %-age change from BASE for QHTAB and
*for selected indicators of MACROTAB (in SINDP)

MACROTAB(SINDP,SIMNB)$SIMCUR(SIMNB)
  = 100*(MACROTAB(SINDP,SIMNB)/MACROTAB(SINDP,'BASE') - 1);

QHTAB(AC,SIMNB)$(SIMCUR(SIMNB)$QHTAB(AC,'BASE'))
  = 100*(QHTAB(AC,SIMNB)/QHTAB(AC,'BASE') - 1);

QATAB(AC,SIMNB)$(SIMCUR(SIMNB)$QATAB(AC,'BASE'))
  = 100*(QATAB(AC,SIMNB)/QATAB(AC,'BASE') - 1);

PATAB(AC,SIMNB)$(SIMCUR(SIMNB)$PATAB(AC,'BASE'))
  = 100*(PATAB(AC,SIMNB)/PATAB(AC,'BASE') - 1);

*==============================================
*Computing deviation from BASE for YFTAB and
*for selected indicators of MACROTAB (in SINDDEV)

MACROTAB(SINDDEV,SIMNB)$SIMCUR(SIMNB)
  = MACROTAB(SINDDEV,SIMNB) - MACROTAB(SINDDEV,'BASE');

YFTAB(AC,SIMNB)$SIMCUR(SIMNB)
  = YFTAB(AC,SIMNB) - YFTAB(AC,'BASE');


*Rounding all values to one decimal point
 MACROTAB(SIND,SIM)   = ROUND(MACROTAB(SIND,SIM),1);
 QHTAB(AC,SIM)        = ROUND(QHTAB(AC,SIM),1);
 YFTAB(AC,SIM)        = ROUND(YFTAB(AC,SIM),1);
 QATAB(AC,SIM)        = ROUND(QATAB(AC,SIM),1);
 PATAB(AC,SIM)        = ROUND(PATAB(AC,SIM),1);

*Displaying only one decimal point
 OPTION DECIMALS=1;

DISPLAY
 MACROTAB
"In the BASE column, aggregate real indicators are measured"
"at base-year values."
"Exchange rates and price indices are set at 100."
"Items with GDP in name are expressed as % of nominal GDP."
""
"Units for non-BASE columns:"
"% changes from BASE for items not computed as GDP shares;"
"deviation from BASE for items computed as GDP shares."

QHTAB
"In the BASE column, quantities are measured at base-year prices."
"The non-BASE columns show % change from BASE."

EVTAB
"In the BASE column, consumption value at base-year prices."
"The non-BASE columns show EV as % of BASE consumption value."

YFTAB
"The BASE column show %-age shares of base factor incomes."
"The non-BASE columns show deviations from BASE."

QATAB
"In the BASE column, quantities are measured at base-year prices."
"The non-BASE columns show % change from BASE."

PATAB
"Base-prices are indexed to 100."
"The non-BASE columns show % change from BASE."
;